'use strict';

var SPEEDYCO_CLIENT_VERSION = '1.2.0';

var axios = require('axios').default;

var resources = {
  Modelli: require('./resources/Modelli'),
  Richieste: require('./resources/Richieste'),
  Richiedenti: require('./resources/Richiedenti'),
  Utenti: require('./resources/Utenti'),
  Utils: require('./resources/Utils')
}

var API_BASE_URL = 'https://sprt.ibs.ve.it/api/v2';

var conn = null;

function Speedyco(apiToken, timeout) {
  if (!(this instanceof Speedyco)) {
    return new Speedyco(apiToken, timeout);
  }

  if (!apiToken) {
    throw 'Speedyco API token not set';
  }

  // 3000ms timeout by default
  var timeout = timeout || 3000;

  var requestMethods = this._prepMethods(apiToken, timeout);

  this._prepResources(requestMethods);
}

Speedyco.prototype = {
    _prepResources: function(requestMethods) {
        for (var name in resources) {
            this[
                name[0].toLowerCase() + name.substring(1)
            ] = new resources[name](requestMethods);
        }
    },
    _prepMethods: function(apiToken, timeout) {
        conn = axios.create({
            baseURL: API_BASE_URL,
            timeout: timeout,
            headers: {
                'X-Speedyco-Client': 'JS/' + SPEEDYCO_CLIENT_VERSION,
                'Authorization': 'Bearer '+ apiToken
            }
        });

        return {
            get: function(url, params) {
                var params = params || {};

                return conn.get(url, {params: params})
            },
            post: function(url, data) {
                var data = data || {};

                return conn.post(url, data)  
            },
            put: function(url, data) {
                var data = data || {};
                
                return conn.put(url, data)  
            },
            delete: function(url) {                
                return conn.delete(url)  
            }
        }
    }
}

module.exports = Speedyco;
